@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.constants import paths
+from hdsr_wis_config_reader import constants
 from hdsr_wis_config_reader.tests.fixtures import loc_sets
 
 import pandas as pd  # noqa pandas comes with geopandas
@@ -336,7 +336,7 @@ expected_attrib_files = [
 
 
 def test_waterstandlocationset(loc_sets):
-    assert loc_sets.waterstandloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
+    assert loc_sets.waterstandloc.fews_config.path == constants.WIS_CONFIG_TEST_DIR
     assert loc_sets.waterstandloc.idmap_section_name == expected_idmap_section_name
     assert loc_sets.waterstandloc.name == expected_name
     assert loc_sets.waterstandloc.csv_filename == expected_csvfile
